@@ -40,7 +40,7 @@ class Arkivist(dict):
         
         self._read_mode = "r+"
         if mode not in ("r", "r+", "w+"):
-            ArkivistException("Unsupported file read mode, use `r`, `r+`, `w+`.")
+            raise ArkivistException("Unsupported file read mode, use `r`, `r+`, `w+`.")
         self._read_mode = mode
 
         self._save_as = None
@@ -59,7 +59,6 @@ class Arkivist(dict):
 
         if not self._is_data and self._filepath:
             self._encrypt, data = _read_json(self._filepath, self._read_mode, self._cypher)
-            self.clear()
             self.update(data)
             self.save()
 
@@ -119,7 +118,7 @@ class Arkivist(dict):
                     self.update(source.json())
             except Exception as e:
                 if not noerror:
-                    ArkivistException(str(e))
+                    raise ArkivistException(str(e))
             _write_json(self)
             return self
 
@@ -462,36 +461,45 @@ def _load_cypher(authfile):
 
 
 def _validate_filepath(filepath, extension="json"):
-    if filepath.split(".")[-1].lower() == extension:
-        return filepath
-    ArkivistException("Unsupported file.")
+    if isinstance(filepath, str:)
+        if filepath.split(".")[-1].lower() == extension:
+            return filepath
+        raise ArkivistException("Unsupported file.")
+    return None
 
 
 def _read_json(filepath, mode, cypher=None):
     """ Read and parse JSON file to Python dictionary. """
     temp = ""
-    encrypted, content = False, {}
+    encrypt, content = False, {}
     filepath = _validate_filepath(filepath)
+    if not isinstance(filepath, str):
+        return encrypt, content
+
     keys = ("arkivist", "encryption", "content")
     try:
         with open(filepath, mode, encoding="utf-8") as f:
             temp = RE_WHITESPACES.sub("", f.read()).strip()
+            if mode == "w+":
+                f.write(temp)
     except:
         with open(filepath, "w", encoding="utf-8") as f:
             f.write("{}")
     if temp[:2] in ("", "{}"):
-        return encrypted, content
+        return encrypt, content
     content = json.loads(temp)
     if len(content) == len(keys):
-        encrypted = all([(key in content) for key in keys])
-        if encrypted and isinstance(cypher, str):
+        encrypt = all([(key in content) for key in keys])
+        if encrypt and cypher is not None:
             if not (
                 content["arkivist"] >= 1.2 and content["encryption"] == "fernet"
             ):
-            ArkivistException("The file is not compatible with Arkivist.")
-            content = content["content"].encode("utf-8")
-            content = json.loads(cypher.decrypt(content).decode())
-    return encrypted, content
+                raise ArkivistException("The file is not compatible with Arkivist.")
+            encrypted = content["content"].encode("utf-8")
+            decrypted = cypher.decrypt(encrypted).decode().strip()
+            decrypted = decrypted if decrypted else "{}"
+            content = json.loads(decrypted)
+    return encrypt, content
 
 def _write_json(obj, forced=False):
     """Write JSON object as string representation into file."""
@@ -501,6 +509,8 @@ def _write_json(obj, forced=False):
     if obj._save_as is not None:
         obj._filepath = obj._save_as
     filepath = _validate_filepath(obj._filepath)
+    if not isinstance(filepath, str):
+        return
 
     dataset = dict(obj)
     autosort = isinstance(obj._autosort, bool) and bool(obj._autosort)
